" Vim syntax file
" Language:      Igor Pro
" Maintainer:    Thomas Braun <thomas.braun at byte-physics dot de>
" Last Modified: 2014-03-18
" Filetype:      *.ipf
" Remark:        Based on the original version by Peter Li <peterli@spam.eriifiic.salk.edu>

" The list of functions and operations has been generated by:
" ###########################################################
" Function gatherDataForVim()
"
" 	string opList   = OperationList("*",";","internal")
" 	string funcList = FunctionList("*",";","KIND:5")
"
" 	OutputVimList("syn keyword igorOperation", opList)
" 	print "\r"
" 	OutputVimList("syn keyword igorFunction", funcList)
" End
"
" Function OutputVimList(prefix,list)
" 	string list, prefix
"
" 	variable numItems = ItemsInList(list,";")
"
" 	string str = prefix
" 	string item
"
" 	variable i
" 	for(i=0; i < numItems; i+=1)
" 		item = StringFromList(i,list)
"
" 		if( strlen(item) <= 1) // skip single character items
" 			continue
" 		endif
"
" 		if( (strlen(str) + strlen(item) + 1) > 80)
" 			print str
" 			str = prefix
" 		endif
" 		str += " " + item
" 	endfor
" End
" ###########################################################

if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

syn case ignore

" Operations {{{
syn keyword igorOperation Abort AddFIFOData AddFIFOVectData AddMovieAudio
syn keyword igorOperation AddMovieFrame AdoptFiles APMath Append AppendImage
syn keyword igorOperation AppendLayoutObject AppendMatrixContour AppendText
syn keyword igorOperation AppendToGraph AppendToLayout AppendToTable
syn keyword igorOperation AppendXYZContour AutoPositionWindow BackgroundInfo
syn keyword igorOperation Beep BoundingBall BrowseURL BuildMenu Button cd Chart
syn keyword igorOperation CheckBox CheckDisplayed ChooseColor Close CloseMovie
syn keyword igorOperation CloseProc ColorScale ColorTab2Wave Concatenate
syn keyword igorOperation ControlBar ControlInfo ControlUpdate ConvexHull
syn keyword igorOperation Convolve CopyFile CopyFolder CopyScales Correlate
syn keyword igorOperation CreateAliasShortcut Cross CtrlBackground CtrlFIFO
syn keyword igorOperation CtrlNamedBackground Cursor CurveFit CustomControl CWT
syn keyword igorOperation Debugger DebuggerOptions DefaultFont
syn keyword igorOperation DefaultGuiControls DefaultGuiFont DefineGuide
syn keyword igorOperation DelayUpdate DeleteFile DeleteFolder DeletePoints
syn keyword igorOperation Differentiate dir Display DisplayHelpTopic
syn keyword igorOperation DisplayProcedure DoAlert DoIgorMenu DoUpdate DoWindow
syn keyword igorOperation DoXOPIdle DrawAction DrawArc DrawBezier DrawLine
syn keyword igorOperation DrawOval DrawPICT DrawPoly DrawRect DrawRRect DrawText
syn keyword igorOperation DSPDetrend DSPPeriodogram Duplicate
syn keyword igorOperation DuplicateDataFolder DWT EdgeStats Edit ErrorBars
syn keyword igorOperation Execute ExecuteScriptText ExperimentModified Extract
syn keyword igorOperation FastGaussTransform FastOp FBinRead FBinWrite FFT
syn keyword igorOperation FIFO2Wave FIFOStatus FilterFIR FilterIIR FindLevel
syn keyword igorOperation FindLevels FindPeak FindPointsInPoly FindRoots
syn keyword igorOperation FindSequence FindValue FPClustering fprintf FReadLine
syn keyword igorOperation FSetPos FStatus FTPCreateDirectory FTPDelete
syn keyword igorOperation FTPDownload FTPUpload FuncFit FuncFitMD GetAxis
syn keyword igorOperation GetFileFolderInfo GetLastUserMenuInfo GetMarquee
syn keyword igorOperation GetMouse GetSelection GetWindow GraphNormal
syn keyword igorOperation GraphWaveDraw GraphWaveEdit Grep GroupBox Hanning
syn keyword igorOperation HideIgorMenus HideInfo HideProcedures HideTools
syn keyword igorOperation HilbertTransform Histogram IFFT ImageAnalyzeParticles
syn keyword igorOperation ImageBlend ImageBoundaryToMask ImageEdgeDetection
syn keyword igorOperation ImageFileInfo ImageFilter ImageFocus ImageFromXYZ
syn keyword igorOperation ImageGenerateROIMask ImageHistModification
syn keyword igorOperation ImageHistogram ImageInterpolate ImageLineProfile
syn keyword igorOperation ImageLoad ImageMorphology ImageRegistration
syn keyword igorOperation ImageRemoveBackground ImageRestore ImageRotate
syn keyword igorOperation ImageSave ImageSeedFill ImageSnake ImageStats
syn keyword igorOperation ImageThreshold ImageTransform ImageUnwrapPhase
syn keyword igorOperation ImageWindow IndexSort InsertPoints Integrate
syn keyword igorOperation IntegrateODE Interp3DPath Interpolate3D KillBackground
syn keyword igorOperation KillControl KillDataFolder KillFIFO KillFreeAxis
syn keyword igorOperation KillPath KillPICTs KillStrings KillVariables KillWaves
syn keyword igorOperation KillWindow KMeans Label Layout Legend
syn keyword igorOperation LinearFeedbackShiftRegister ListBox LoadData
syn keyword igorOperation LoadPackagePreferences LoadPICT LoadWave Loess
syn keyword igorOperation LombPeriodogram Make MakeIndex MarkPerfTestTime
syn keyword igorOperation MatrixConvolve MatrixCorr MatrixEigenV MatrixFilter
syn keyword igorOperation MatrixGaussJ MatrixInverse MatrixLinearSolve
syn keyword igorOperation MatrixLinearSolveTD MatrixLLS MatrixLUBkSub MatrixLUD
syn keyword igorOperation MatrixMultiply MatrixOP MatrixSchur MatrixSolve
syn keyword igorOperation MatrixSVBkSub MatrixSVD MatrixTranspose
syn keyword igorOperation MeasureStyledText Modify ModifyContour ModifyControl
syn keyword igorOperation ModifyControlList ModifyFreeAxis ModifyGraph
syn keyword igorOperation ModifyImage ModifyLayout ModifyPanel ModifyTable
syn keyword igorOperation ModifyWaterfall MoveDataFolder MoveFile MoveFolder
syn keyword igorOperation MoveString MoveSubwindow MoveVariable MoveWave
syn keyword igorOperation MoveWindow NeuralNetworkRun NeuralNetworkTrain
syn keyword igorOperation NewDataFolder NewFIFO NewFIFOChan NewFreeAxis NewImage
syn keyword igorOperation NewLayout NewMovie NewNotebook NewPanel NewPath
syn keyword igorOperation NewWaterfall Note Notebook NotebookAction Open
syn keyword igorOperation OpenNotebook Optimize ParseOperationTemplate PathInfo
syn keyword igorOperation PauseForUser PauseUpdate PCA PlayMovie PlayMovieAction
syn keyword igorOperation PlaySnd PlaySound PopupContextualMenu PopupMenu
syn keyword igorOperation Preferences PrimeFactors Print printf PrintGraphs
syn keyword igorOperation PrintLayout PrintNotebook PrintSettings PrintTable
syn keyword igorOperation Project PulseStats PutScrapText pwd Quit
syn keyword igorOperation RatioFromNumber Redimension Remove RemoveContour
syn keyword igorOperation RemoveFromGraph RemoveFromLayout RemoveFromTable
syn keyword igorOperation RemoveImage RemoveLayoutObjects RemovePath Rename
syn keyword igorOperation RenameDataFolder RenamePath RenamePICT RenameWindow
syn keyword igorOperation ReorderImages ReorderTraces ReplaceText ReplaceWave
syn keyword igorOperation Resample ResumeUpdate Reverse Rotate Save SaveData
syn keyword igorOperation SaveExperiment SaveGraphCopy SaveNotebook
syn keyword igorOperation SavePackagePreferences SavePICT SaveTableCopy
syn keyword igorOperation SetActiveSubwindow SetAxis SetBackground
syn keyword igorOperation SetDashPattern SetDataFolder SetDimLabel SetDrawEnv
syn keyword igorOperation SetDrawLayer SetFileFolderInfo SetFormula SetIgorHook
syn keyword igorOperation SetIgorMenuMode SetIgorOption SetMarquee
syn keyword igorOperation SetProcessSleep SetRandomSeed SetScale SetVariable
syn keyword igorOperation SetWaveLock SetWindow ShowIgorMenus ShowInfo ShowTools
syn keyword igorOperation Silent Sleep Slider Smooth SmoothCustom Sort
syn keyword igorOperation SoundInRecord SoundInSet SoundInStartChart
syn keyword igorOperation SoundInStatus SoundInStopChart SphericalInterpolate
syn keyword igorOperation SphericalTriangulate SplitString sprintf sscanf Stack
syn keyword igorOperation StackWindows StatsAngularDistanceTest StatsANOVA1Test
syn keyword igorOperation StatsANOVA2NRTest StatsANOVA2RMTest StatsANOVA2Test
syn keyword igorOperation StatsChiTest StatsCircularCorrelationTest
syn keyword igorOperation StatsCircularMeans StatsCircularMoments
syn keyword igorOperation StatsCircularTwoSampleTest StatsCochranTest
syn keyword igorOperation StatsContingencyTable StatsDIPTest StatsDunnettTest
syn keyword igorOperation StatsFriedmanTest StatsFTest StatsHodgesAjneTest
syn keyword igorOperation StatsJBTest StatsKendallTauTest StatsKSTest
syn keyword igorOperation StatsKWTest StatsLinearCorrelationTest
syn keyword igorOperation StatsLinearRegression StatsMultiCorrelationTest
syn keyword igorOperation StatsNPMCTest StatsNPNominalSRTest StatsQuantiles
syn keyword igorOperation StatsRankCorrelationTest StatsResample StatsSample
syn keyword igorOperation StatsScheffeTest StatsSignTest StatsSRTest StatsTTest
syn keyword igorOperation StatsTukeyTest StatsVariancesTest
syn keyword igorOperation StatsWatsonUSquaredTest StatsWatsonWilliamsTest
syn keyword igorOperation StatsWheelerWatsonTest StatsWilcoxonRankTest
syn keyword igorOperation StatsWRCorrelationTest String StructGet StructPut
syn keyword igorOperation TabControl Tag TextBox ThreadGroupPutDF ThreadStart
syn keyword igorOperation Tile TileWindows TitleBox ToCommandLine ToolsGrid
syn keyword igorOperation Triangulate3d Unwrap ValDisplay Variable WaveMeanStdv
syn keyword igorOperation WaveStats WaveTransform wfprintf WignerTransform
" }}}

" Functions {{{
syn keyword igorFunction GetBrowserSelection GetBrowserLine GizmoInfo
syn keyword igorFunction MPFXGaussPeak MPFXLorenzianPeak MPFXVoigtPeak
syn keyword igorFunction MPFXEMGPeak MPFXExpConvExpPeak HDF5DatasetInfo
syn keyword igorFunction HDF5AttributeInfo HDF5TypeInfo GaussFit GaussFitBL
syn keyword igorFunction GaussFit1Width GaussFit1WidthBL LorentzianFit
syn keyword igorFunction LorentzianFitBL LorentzianFit1Width
syn keyword igorFunction LorentzianFit1WidthBL Voigt VoigtFit VoigtFitBL
syn keyword igorFunction VoigtFit1Shape VoigtFit1ShapeBL VoigtFit1Shape1Width
syn keyword igorFunction VoigtFit1Shape1WidthBL ExpGauss ExpGaussFit
syn keyword igorFunction ExpGaussFitBL ExpGaussFit1Shape ExpGaussFit1ShapeBL
syn keyword igorFunction ExpConvExp ExpConvExpFit ExpConvExpFitBL
syn keyword igorFunction ExpConvExpFit1Shape ExpConvExpFit1ShapeBL
syn keyword igorFunction tango_open_device tango_close_device
syn keyword igorFunction tango_command_inout tango_read_attribute
syn keyword igorFunction tango_read_attributes tango_write_attribute
syn keyword igorFunction tango_write_attributes tango_get_dev_status
syn keyword igorFunction tango_ping_device tango_set_dev_timeout
syn keyword igorFunction tango_get_dev_timeout tango_get_dev_cmd_list
syn keyword igorFunction tango_get_dev_attr_list tango_get_dev_black_box
syn keyword igorFunction tango_get_error_stack tango_start_attr_monitor
syn keyword igorFunction tango_stop_attr_monitor tango_suspend_attr_monitor
syn keyword igorFunction tango_resume_attr_monitor tango_set_attr_monitor_period
syn keyword igorFunction tango_compute_image_proj abs acos acosh AiryA AiryAD
syn keyword igorFunction AiryB AiryBD alog area areaXY asin asinh atan atan2
syn keyword igorFunction atanh AxisValFromPixel Besseli Besselj Besselk Bessely
syn keyword igorFunction beta betai BinarySearch BinarySearchInterp binomial
syn keyword igorFunction binomialln binomialNoise cabs CaptureHistoryStart ceil
syn keyword igorFunction cequal char2num chebyshev chebyshevU CheckName cmplx
syn keyword igorFunction cmpstr conj ContourZ cos cosh cot coth CountObjects
syn keyword igorFunction CountObjectsDFR cpowi CreationDate csc DataFolderExists
syn keyword igorFunction DataFolderRefsEqual DataFolderRefStatus date2secs
syn keyword igorFunction datetime DateToJulian Dawson DDEExecute DDEInitiate
syn keyword igorFunction DDEPokeString DDEPokeWave DDERequestWave DDEStatus
syn keyword igorFunction DDETerminate defined deltax digamma DimDelta DimOffset
syn keyword igorFunction DimSize ei enoise equalWaves erf erfc erfcw exists exp
syn keyword igorFunction expInt expNoise factorial fakedata faverage faverageXY
syn keyword igorFunction FindDimLabel FindListItem floor FontSizeHeight
syn keyword igorFunction FontSizeStringWidth FresnelCos FresnelSin gamma
syn keyword igorFunction gammaInc gammaNoise gammln gammp gammq Gauss Gauss1D
syn keyword igorFunction Gauss2D gcd GetDefaultFontSize GetDefaultFontStyle
syn keyword igorFunction GetKeyState GetRTError GetRTLocation gnoise GrepString
syn keyword igorFunction hcsr hermite hermiteGauss HyperG0F1 HyperG1F1 HyperG2F1
syn keyword igorFunction HyperGNoise HyperGPFQ IgorVersion ilim imag Inf
syn keyword igorFunction Integrate1D interp Interp2D Interp3D inverseERF
syn keyword igorFunction inverseERFC ItemsInList jlim Laguerre LaguerreA
syn keyword igorFunction LaguerreGauss leftx LegendreA limit ln log
syn keyword igorFunction logNormalNoise lorentzianNoise magsqr MandelbrotPoint
syn keyword igorFunction MarcumQ MatrixDet MatrixDot MatrixRank MatrixTrace max
syn keyword igorFunction mean min mod ModDate NaN norm NumberByKey numpnts
syn keyword igorFunction numtype NumVarOrDefault NVAR_Exists p2rect
syn keyword igorFunction ParamIsDefault pcsr Pi PixelFromAxisVal pnt2x
syn keyword igorFunction poissonNoise poly poly2D PolygonArea qcsr r2polar real
syn keyword igorFunction rightx round sawtooth ScreenResolution sec SelectNumber
syn keyword igorFunction sign sin sinc sinh SphericalBessJ SphericalBessJD
syn keyword igorFunction SphericalBessY SphericalBessYD SphericalHarmonics sqrt
syn keyword igorFunction StartMSTimer StatsBetaCDF StatsBetaPDF StatsBinomialCDF
syn keyword igorFunction StatsBinomialPDF StatsCauchyCDF StatsCauchyPDF
syn keyword igorFunction StatsChiCDF StatsChiPDF StatsCMSSDCDF StatsCorrelation
syn keyword igorFunction StatsDExpCDF StatsDExpPDF StatsErlangCDF StatsErlangPDF
syn keyword igorFunction StatsErrorPDF StatsEValueCDF StatsEValuePDF StatsExpCDF
syn keyword igorFunction StatsExpPDF StatsFCDF StatsFPDF StatsFriedmanCDF
syn keyword igorFunction StatsGammaCDF StatsGammaPDF StatsGeometricCDF
syn keyword igorFunction StatsGeometricPDF StatsHyperGCDF StatsHyperGPDF
syn keyword igorFunction StatsInvBetaCDF StatsInvBinomialCDF StatsInvCauchyCDF
syn keyword igorFunction StatsInvChiCDF StatsInvCMSSDCDF StatsInvDExpCDF
syn keyword igorFunction StatsInvEValueCDF StatsInvExpCDF StatsInvFCDF
syn keyword igorFunction StatsInvFriedmanCDF StatsInvGammaCDF
syn keyword igorFunction StatsInvGeometricCDF StatsInvKuiperCDF
syn keyword igorFunction StatsInvLogisticCDF StatsInvLogNormalCDF
syn keyword igorFunction StatsInvMaxwellCDF StatsInvMooreCDF
syn keyword igorFunction StatsInvNBinomialCDF StatsInvNCChiCDF StatsInvNCFCDF
syn keyword igorFunction StatsInvNormalCDF StatsInvParetoCDF StatsInvPoissonCDF
syn keyword igorFunction StatsInvPowerCDF StatsInvQCDF StatsInvQpCDF
syn keyword igorFunction StatsInvRayleighCDF StatsInvRectangularCDF
syn keyword igorFunction StatsInvSpearmanCDF StatsInvStudentCDF
syn keyword igorFunction StatsInvTopDownCDF StatsInvTriangularCDF
syn keyword igorFunction StatsInvUsquaredCDF StatsInvVonMisesCDF
syn keyword igorFunction StatsInvWeibullCDF StatsKuiperCDF StatsLogisticCDF
syn keyword igorFunction StatsLogisticPDF StatsLogNormalCDF StatsLogNormalPDF
syn keyword igorFunction StatsMaxwellCDF StatsMaxwellPDF StatsMedian
syn keyword igorFunction StatsMooreCDF StatsNBinomialCDF StatsNBinomialPDF
syn keyword igorFunction StatsNCChiCDF StatsNCChiPDF StatsNCFCDF StatsNCFPDF
syn keyword igorFunction StatsNCTCDF StatsNCTPDF StatsNormalCDF StatsNormalPDF
syn keyword igorFunction StatsParetoCDF StatsParetoPDF StatsPermute
syn keyword igorFunction StatsPoissonCDF StatsPoissonPDF StatsPowerCDF
syn keyword igorFunction StatsPowerNoise StatsPowerPDF StatsQCDF StatsQpCDF
syn keyword igorFunction StatsRayleighCDF StatsRayleighPDF StatsRectangularCDF
syn keyword igorFunction StatsRectangularPDF StatsRunsCDF StatsSpearmanRhoCDF
syn keyword igorFunction StatsStudentCDF StatsStudentPDF StatsTopDownCDF
syn keyword igorFunction StatsTriangularCDF StatsTriangularPDF StatsTrimmedMean
syn keyword igorFunction StatsUSquaredCDF StatsVonMisesCDF StatsVonMisesNoise
syn keyword igorFunction StatsVonMisesPDF StatsWaldCDF StatsWaldPDF
syn keyword igorFunction StatsWeibullCDF StatsWeibullPDF StopMSTimer str2num
syn keyword igorFunction stringCRC stringmatch strlen strsearch StudentA
syn keyword igorFunction StudentT sum SVAR_Exists TagVal tan tanh
syn keyword igorFunction ThreadGroupCreate ThreadGroupRelease ThreadGroupWait
syn keyword igorFunction ThreadProcessorCount ThreadReturnValue ticks trunc
syn keyword igorFunction Variance vcsr WaveCRC WaveDims WaveExists WaveMax
syn keyword igorFunction WaveMin WaveRefsEqual WaveType WhichListItem WinType
syn keyword igorFunction WNoise x2pnt xcsr zcsr ZernikeR AddListItem
syn keyword igorFunction AnnotationInfo AnnotationList AxisInfo AxisList
syn keyword igorFunction CaptureHistory ChildWindowList CleanupName ContourInfo
syn keyword igorFunction ContourNameList ControlNameList CsrInfo CsrWave
syn keyword igorFunction CsrXWave CTabList DataFolderDir date DDERequestString
syn keyword igorFunction FetchURL FontList FuncRefInfo FunctionInfo FunctionList
syn keyword igorFunction FunctionPath GetDataFolder GetDefaultFont GetDimLabel
syn keyword igorFunction GetErrMessage GetFormula GetIndependentModuleName
syn keyword igorFunction GetIndexedObjName GetIndexedObjNameDFR GetRTErrMessage
syn keyword igorFunction GetRTLocInfo GetRTStackInfo GetScrapText GetUserData
syn keyword igorFunction GetWavesDataFolder GrepList GuideInfo GuideNameList
syn keyword igorFunction Hash IgorInfo ImageInfo ImageNameList
syn keyword igorFunction IndependentModuleList IndexedDir IndexedFile
syn keyword igorFunction JulianToDate LayoutInfo ListMatch LowerStr MacroList
syn keyword igorFunction NameOfWave note num2char num2istr num2str OperationList
syn keyword igorFunction PadString ParseFilePath PathList PICTInfo PICTList
syn keyword igorFunction PossiblyQuoteName ProcedureText RemoveByKey
syn keyword igorFunction RemoveEnding RemoveFromList RemoveListItem
syn keyword igorFunction ReplaceNumberByKey ReplaceString ReplaceStringByKey
syn keyword igorFunction Secs2Date Secs2Time SelectString SortList
syn keyword igorFunction SpecialCharacterInfo SpecialCharacterList
syn keyword igorFunction SpecialDirPath StringByKey StringFromList StringList
syn keyword igorFunction StrVarOrDefault TableInfo TextFile ThreadGroupGetDF
syn keyword igorFunction time TraceFromPixel TraceInfo TraceNameList UniqueName
syn keyword igorFunction UnPadString UpperStr URLDecode URLEncode VariableList
syn keyword igorFunction WaveInfo WaveList WaveName WaveUnits WinList WinName
syn keyword igorFunction WinRecreation XWaveName ContourNameToWaveRef CsrWaveRef
syn keyword igorFunction CsrXWaveRef ImageNameToWaveRef NewFreeWave TagWaveRef
syn keyword igorFunction TraceNameToWaveRef WaveRefIndexed WaveRefIndexedDFR
syn keyword igorFunction XWaveRefFromTrace GetDataFolderDFR
syn keyword igorFunction GetWavesDataFolderDFR NewFreeDataFolder
" }}}

syn region  igorStringDQ  start=+"+ end=+"+ skip=+\\"+
syn region  igorStringQ   start=+'+ end=+'+ skip=+\\'+

syn keyword igorStructure struct structure endstructure
syn keyword igorConstant  nan inf
syn keyword igorStat      break return continue
syn keyword igorCond      if else elseif endif switch endswitch
syn keyword igorRepeat    for endfor do while
syn keyword igorLabel     case default
syn match   igorSpecial   "\(V\|S\)_[a-zA-Z]\+" " auto variables from operations like V_flag, S_names etc.

syn keyword igorDefine    threadsafe static macro function window menu end

syn keyword igorType      wave constant strconstant variable string svar
syn keyword igorType      nvar funcref dfref
syn keyword igorType      char uchar int16 uint16 int32 uint32 float double

syn match   igorPreproc   "^#\(pragma\|define\|if\|elif\|endif\|ifdef\|ifndef\|include\|undef\)"
syn match   igorDelimiter "[(){}]\|\[\|\]"

syn match   igorComment   "//.*"   contains=igorTODO
syn match   igorTODO      "todo.*" contained

if exists("igorpro_default_colors")
  hi igorStructure guifg=#0000FF ctermfg=21*
  hi igorConstant  guifg=#C34E00 ctermfg=21*
  hi igorDefine    guifg=#0000FF ctermfg=21*
  hi igorType      guifg=#0000FF ctermfg=21*
  hi igorCond      guifg=#0000FF ctermfg=21*
  hi igorStat      guifg=#0000FF ctermfg=21*
  hi igorRepeat    guifg=#0000FF ctermfg=21*
  hi igorLabel     guifg=#0000FF ctermfg=21*

  hi igorFunction  guifg=#C34E00 ctermfg=166*
  hi igorOperation guifg=#007575 ctermfg=30*
  hi igorPreProc   guifg=#CC00A3 ctermfg=165*
  hi igorStringDQ  guifg=#009C00 ctermfg=28*
  hi igorStringQ   guifg=#009C00 ctermfg=28*
  hi igorComment   guifg=#FF0000 ctermfg=196*
else
  hi link igorOperation Function
  hi link igorFunction  Function

  hi link igorStringDQ  String
  hi link igorStringQ   String

  hi link igorStructure Structure
  hi link igorConstant  Constant
  hi link igorCond      Conditional
  hi link igorStat      Statement
  hi link igorRepeat    Repeat
  hi link igorLabel     Label
  hi link igorSpecial   Special

  hi link igorDefine    Define
  hi link igorType      Type
  hi link igorPreproc   PreProc
  hi link igorDelimiter Delimiter
  hi link igorComment   Comment
  hi link igorTODO      Todo
endif

let b:current_syntax = "igorpro"

" vim: set fdm=marker:
